package org.jeecg.modules.flowpath.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.flowpath.entity.ItdmRunFlowPathStep;
import org.jeecg.modules.flowpath.service.IItdmRunFlowPathStepService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;

 /**
 * @Description: 运行流程步骤表
 * @Author: jeecg-boot
 * @Date:   2023-07-20
 * @Version: V1.0
 */
@Api(tags="运行流程步骤表")
@RestController
@RequestMapping("/flowpath/itdmRunFlowPathStep")
@Slf4j
public class ItdmRunFlowPathStepController extends JeecgController<ItdmRunFlowPathStep, IItdmRunFlowPathStepService> {
	@Autowired
	private IItdmRunFlowPathStepService itdmRunFlowPathStepService;
	
	/**
	 * 分页列表查询
	 *
	 * @param itdmRunFlowPathStep
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "运行流程步骤表-分页列表查询")
	@ApiOperation(value="运行流程步骤表-分页列表查询", notes="运行流程步骤表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<ItdmRunFlowPathStep>> queryPageList(ItdmRunFlowPathStep itdmRunFlowPathStep,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<ItdmRunFlowPathStep> queryWrapper = QueryGenerator.initQueryWrapper(itdmRunFlowPathStep, req.getParameterMap());
		Page<ItdmRunFlowPathStep> page = new Page<ItdmRunFlowPathStep>(pageNo, pageSize);
		IPage<ItdmRunFlowPathStep> pageList = itdmRunFlowPathStepService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param itdmRunFlowPathStep
	 * @return
	 */
	@AutoLog(value = "运行流程步骤表-添加")
	@ApiOperation(value="运行流程步骤表-添加", notes="运行流程步骤表-添加")
	//@RequiresPermissions("org.jeecg.modules:itdm_run_flow_path_step:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody ItdmRunFlowPathStep itdmRunFlowPathStep) {
		itdmRunFlowPathStepService.save(itdmRunFlowPathStep);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param itdmRunFlowPathStep
	 * @return
	 */
	@AutoLog(value = "运行流程步骤表-编辑")
	@ApiOperation(value="运行流程步骤表-编辑", notes="运行流程步骤表-编辑")
	//@RequiresPermissions("org.jeecg.modules:itdm_run_flow_path_step:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody ItdmRunFlowPathStep itdmRunFlowPathStep) {
		itdmRunFlowPathStepService.updateById(itdmRunFlowPathStep);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "运行流程步骤表-通过id删除")
	@ApiOperation(value="运行流程步骤表-通过id删除", notes="运行流程步骤表-通过id删除")
	//@RequiresPermissions("org.jeecg.modules:itdm_run_flow_path_step:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		itdmRunFlowPathStepService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "运行流程步骤表-批量删除")
	@ApiOperation(value="运行流程步骤表-批量删除", notes="运行流程步骤表-批量删除")
	//@RequiresPermissions("org.jeecg.modules:itdm_run_flow_path_step:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.itdmRunFlowPathStepService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "运行流程步骤表-通过id查询")
	@ApiOperation(value="运行流程步骤表-通过id查询", notes="运行流程步骤表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<ItdmRunFlowPathStep> queryById(@RequestParam(name="id",required=true) String id) {
		ItdmRunFlowPathStep itdmRunFlowPathStep = itdmRunFlowPathStepService.getById(id);
		if(itdmRunFlowPathStep==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(itdmRunFlowPathStep);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param itdmRunFlowPathStep
    */
    //@RequiresPermissions("org.jeecg.modules:itdm_run_flow_path_step:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, ItdmRunFlowPathStep itdmRunFlowPathStep) {
        return super.exportXls(request, itdmRunFlowPathStep, ItdmRunFlowPathStep.class, "运行流程步骤表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    //@RequiresPermissions("itdm_run_flow_path_step:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, ItdmRunFlowPathStep.class);
    }

}
